@@ -115,11 +115,12 @@ def sdist2rpm(sdist, dist_dir=None, version=None):
             dist_dir = old_dir
 
         # looking for a file named sdist.arch.rpm
-        name = sdist
-        if name.startswith('python-'):
+        name = sdist.lower()
+        if not name.startswith('python'):
+            name = '%s-%s' % (_PYTHON, name)
+        elif name.startswith('python-'):
             name = '%s-%s' % (_PYTHON, name[len('python-'):])
 
-
         found = []
         for file_ in os.listdir(dist_dir):
             if file_.startswith(name):
